@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #    Copyright (C) 2013  Sebastian Marro <smarro@gnusolidario.org>
 #
@@ -23,26 +22,31 @@
 ##############################################################################
 
 from trytond.pool import Pool
-from .health_stock import *
-from .wizard import *
+from . import health_stock
+from . import wizard
+
 
 def register():
     Pool.register(
-        Party,
-        Lot,
-        Move,
-        PatientAmbulatoryCare,
-        PatientAmbulatoryCareMedicament,
-        PatientAmbulatoryCareMedicalSupply,
-        PatientRounding,
-        PatientRoundingMedicament,
-        PatientRoundingMedicalSupply,
-        PatientPrescriptionOrder,
-        PatientVaccination,
+        health_stock.Party,
+        health_stock.Lot,
+        health_stock.Move,
+        health_stock.PatientAmbulatoryCare,
+        health_stock.PatientAmbulatoryCareMedicament,
+        health_stock.PatientAmbulatoryCareMedicalSupply,
+        health_stock.PatientRounding,
+        health_stock.PatientRoundingMedicament,
+        health_stock.PatientRoundingMedicalSupply,
+        health_stock.PatientPrescriptionOrder,
+        health_stock.PatientVaccination,
+        wizard.wizard_create_prescription_stock_move.
         CreatePrescriptionStockMoveInit,
+        wizard.wizard_create_vaccination_stock_move.
         CreateVaccinationStockMoveInit,
         module='health_stock', type_='model')
     Pool.register(
+        wizard.wizard_create_prescription_stock_move.
         CreatePrescriptionStockMove,
+        wizard.wizard_create_vaccination_stock_move.
         CreateVaccinationStockMove,
         module='health_stock', type_='wizard')
