@@ -2,8 +2,8 @@
 ##############################################################################
 #
 #    GNU Health: The Free Health and Hospital Information System
-#    Copyright (C) 2008-2021 Luis Falcon <lfalcon@gnusolidario.org>
-#    Copyright (C) 2011-2021 GNU Solidario <health@gnusolidario.org>
+#    Copyright (C) 2008-2022 Luis Falcon <lfalcon@gnusolidario.org>
+#    Copyright (C) 2011-2022 GNU Solidario <health@gnusolidario.org>
 #
 #
 #    This program is free software: you can redistribute it and/or modify
@@ -22,21 +22,23 @@
 ##############################################################################
 
 from trytond.pool import Pool
-from .health_surgery import *
-from .report import *
+from . import health_surgery
+from . import report
+from . import sequences
+from . import exceptions
 
 def register():
     Pool.register(
-		GnuHealthSequences,
-        GnuHealthSequenceSetup,
-        RCRI,
-        Surgery,
-        Operation,
-        SurgeryMainProcedure,
-        SurgerySupply,
-        PatientData,
-        SurgeryTeam,
+		sequences.GnuHealthSequences,
+        sequences.SurgeryCodeSequence,
+        health_surgery.RCRI,
+        health_surgery.Surgery,
+        health_surgery.Operation,
+        health_surgery.SurgeryMainProcedure,
+        health_surgery.SurgerySupply,
+        health_surgery.PatientData,
+        health_surgery.SurgeryTeam,
         module='health_surgery', type_='model')
     Pool.register(
-        SurgeryReport,
+        report.SurgeryReport,
         module='health_surgery', type_='report')
